@@ -4,7 +4,7 @@ import ntpath
 import sys
 import datetime
 
-from ffmpy      import FFmpeg
+from cv2        import cv2
 from PIL        import Image
 from PIL        import ImageFont
 from PIL        import ImageDraw
@@ -286,19 +286,54 @@ def imageText(video_path, secure_tmp, bg_width, bg_height, custom_text,
 
     return y + 5
 
+def timestamps(folder, font_dir, font_size, timelist):
+    if font_dir == '':
+        font_name = os.path.join(packagePath(), 'fonts', 'RobotoCondensed-Regular.ttf')
+
+    font_size = 20
+
+    count = -1
+    resized_images = os.listdir(folder)
+    resized_images.sort(key=lambda f: int(re.sub('\\D', '', f)))
+    for img in resized_images:
+        count += 1
+        image = Image.open(os.path.join(folder, img))
+        img_width, img_height = image.size
+
+        text = str(datetime.timedelta(seconds=round(timelist[count])))
+        text_width, text_height = font_info(text, font_name, font_size)
+        x = img_width - text_width - 10
+        y = img_height - text_height - 10
+
+        font = ImageFont.truetype(font_name, font_size)
+
+        draw = ImageDraw.Draw(image)
+        draw.text((x, y), text , (255,255,255), font=font, stroke_width=2, stroke_fill=(0,0,0))
+        image.save(os.path.join(folder, (img)))
+
 def screenshots(video_path, screenshot_folder):
     for img in os.listdir(screenshot_folder):
         os.remove(os.path.join(screenshot_folder, img))
 
-    video_duration = int(round(float(video_info(video_path)[2]['duration']), 2))
-    frame_time = round(video_duration / read_config('images'), 2)
+    images = int(read_config('images'))
+    timestamp = round(float(video_info(video_path)[2]['duration'])) / (images + 1)
+    playtime = timestamp # if playtime = 0, it captures the first frame of the video
+    ss_time = []
+    count = 1
 
-    event = FFmpeg(inputs={video_path: None}, \
-            outputs={os.path.join(screenshot_folder, '%d.png'): \
-            ['-hide_banner', '-nostats', '-loglevel', '0', '-vf', 'fps=1/' + str(frame_time)]})
-    event.run()
+    for _ in range(0, images):
+        ss_time.append(playtime)
+        playtime += timestamp
 
-    return True
+    vidcap = cv2.VideoCapture(video_path)
+    for time in ss_time:
+        vidcap.set(cv2.CAP_PROP_POS_MSEC, time*1000)
+        success, image = vidcap.read()
+        if success:
+            cv2.imwrite(os.path.join(screenshot_folder, str(count)) + ".jpg", image)
+        count += 1
+
+    return ss_time
 
 def resize(screenshot_folder, resize_folder):
     for img in os.listdir(resize_folder):
